@@ -76,14 +76,15 @@ Relation::~Relation()
 
 void Relation::setLayer(Layer* L)
 {
-    if (L)
+    if (L) {
         for (int i=0; i<p->Members.size(); ++i)
             if (p->Members[i].second)
                 p->Members[i].second->setParentFeature(this);
-    else
+    } else {
         for (int i=0; i<p->Members.size(); ++i)
             if (p->Members[i].second)
                 p->Members[i].second->unsetParentFeature(this);
+    }
     Feature::setLayer(L);
 }
 
@@ -122,7 +123,7 @@ CoordBox Relation::boundingBox() const
             CoordBox Clip;
             bool haveFirst = false;
             for (int i=0; i<p->Members.size(); ++i)
-                if (p->Members[i].second && !p->Members[i].second->notEverythingDownloaded() && !CAST_RELATION(p->Members[i].second)) {
+                if (p->Members[i].second && !p->Members[i].second->notEverythingDownloaded()/* && !CAST_RELATION(p->Members[i].second)*/) {
                     if (!haveFirst) {
                         Clip = p->Members[i].second->boundingBox();
                         haveFirst = true;
@@ -187,7 +188,7 @@ void Relation::drawHover(QPainter& P, MapView* theView, bool solid)
         for (int i=0; i<p->Members.size(); ++i)
             if (p->Members[i].second && !p->Members[i].second->isDeleted())
                 if (p->Members[i].second->boundingBox().intersects(theView->viewport()))
-                    p->Members[i].second->drawHover(P,theView, solid);
+                    p->Members[i].second->drawHover(P,theView, false);
 
         if (M_PREFS->getShowParents()) {
             for (int i=0; i<sizeParents(); ++i)
@@ -237,20 +238,21 @@ double Relation::pixelDistance(const QPointF& Target, double ClearEndDistance, b
     //	}
     //}
 
+
     double D;
-    QRectF bb = QRectF(theView->toView(boundingBox().topLeft()),theView->toView(boundingBox().bottomRight()));
+    //QRectF bb = QRectF(theView->toView(boundingBox().bottomLeft()),theView->toView(boundingBox().topRight()));
     //bb.adjust(-10, -10, 10, 10);
 
-    LineF F(bb.topLeft(), bb.topRight());
+    LineF F(theView->toView(boundingBox().topLeft()), theView->toView(boundingBox().topRight()));
     D = F.capDistance(Target);
     if ((D < ClearEndDistance) && (D<Best)) Best = D;
-    F = LineF(bb.topLeft(), bb.bottomLeft());
+    F = LineF(theView->toView(boundingBox().topLeft()), theView->toView(boundingBox().bottomLeft()));
     D = F.capDistance(Target);
     if ((D < ClearEndDistance) && (D<Best)) Best = D;
-    F = LineF(bb.bottomRight(), bb.bottomLeft());
+    F = LineF(theView->toView(boundingBox().bottomRight()), theView->toView(boundingBox().bottomLeft()));
     D = F.capDistance(Target);
     if ((D < ClearEndDistance) && (D<Best)) Best = D;
-    F = LineF(bb.bottomRight(), bb.topRight());
+    F = LineF(theView->toView(boundingBox().bottomRight()), theView->toView(boundingBox().topRight()));
     D = F.capDistance(Target);
     if ((D < ClearEndDistance) && (D<Best)) Best = D;
 
@@ -300,10 +302,12 @@ void Relation::add(const QString& Role, Feature* F)
     F->setParentFeature(this);
     p->BBoxUpToDate = false;
     MetaUpToDate = false;
-    if (layer()) {
+    if (layer() && !isDeleted() && isVisible()) {
         CoordBox bb = boundingBox();
         layer()->indexAdd(bb, this);
     }
+
+    notifyChanges();
 }
 
 void Relation::add(const QString& Role, Feature* F, int Idx)
@@ -315,10 +319,12 @@ void Relation::add(const QString& Role, Feature* F, int Idx)
     F->setParentFeature(this);
     p->BBoxUpToDate = false;
     MetaUpToDate = false;
-    if (layer()) {
+    if (layer() && !isDeleted() && isVisible()) {
         CoordBox bb = boundingBox();
         layer()->indexAdd(bb, this);
     }
+
+    notifyChanges();
 }
 
 void Relation::remove(int Idx)
@@ -332,10 +338,12 @@ void Relation::remove(int Idx)
     p->Members.erase(p->Members.begin()+Idx);
     p->BBoxUpToDate = false;
     MetaUpToDate = false;
-    if (layer()) {
+    if (layer() && !isDeleted() && isVisible()) {
         CoordBox bb = boundingBox();
         layer()->indexAdd(bb, this);
     }
+
+    notifyChanges();
 }
 
 void Relation::remove(Feature* F)
@@ -408,8 +416,17 @@ void Relation::buildPath(Projection const &theProjection, const QTransform& /*th
     if (!p->Members.size())
         return;
 
-    QRectF bb = QRectF(theProjection.project(boundingBox().bottomLeft()),theProjection.project(boundingBox().topRight()));
-    p->theBoundingPath.addRect(bb);
+    QVector<QPointF>theVector;
+    theVector.append(theProjection.project(boundingBox().bottomLeft()));
+    theVector.append(theProjection.project(boundingBox().topLeft()));
+    theVector.append(theProjection.project(boundingBox().topRight()));
+    theVector.append(theProjection.project(boundingBox().bottomRight()));
+    theVector.append(theProjection.project(boundingBox().bottomLeft()));
+
+    //QRectF bb = QPolygonF(theVector).boundingRect();
+    //p->theBoundingPath.addRect(bb);
+
+    p->theBoundingPath.addPolygon(QPolygonF(theVector));
 
     p->theBoundingPath = p->theBoundingPath.intersected(clipPath);
 }
