@@ -228,10 +228,12 @@ void Way::add(Node* Pt, int Idx)
     p->SmoothedUpToDate = false;
     p->wasPathComplete = false;
     p->VirtualsUptodate = false;
-    if (layer()) {
+    if (layer() && !isDeleted() && isVisible()) {
         CoordBox bb = boundingBox();
         layer()->indexAdd(bb, this);
     }
+
+    notifyChanges();
 }
 
 int Way::find(Feature* Pt) const
@@ -266,10 +268,12 @@ void Way::remove(int idx)
     p->SmoothedUpToDate = false;
     p->wasPathComplete = false;
     p->VirtualsUptodate = false;
-    if (layer()) {
+    if (layer() && !isDeleted() && isVisible()) {
         CoordBox bb = boundingBox();
         layer()->indexAdd(bb, this);
     }
+
+    notifyChanges();
 }
 
 void Way::remove(Feature* F)
@@ -1059,6 +1063,7 @@ QString Way::toHtml()
     D += "<i>"+QApplication::translate("MapFeature", "Botright")+": </i>" + QString::number(coordToAng(bb.bottomRight().lat()), 'f', 4) + " / " + QString::number(coordToAng(bb.bottomRight().lon()), 'f', 4);
 
     QString type = isClosed() ? QApplication::translate("MapFeature", "Area") : QApplication::translate("MapFeature", "Way");
+
     return Feature::toMainHtml(type, "way").arg(D);
 }
 
